require "spec_helper"

describe OmniAuth::Strategies::WonderfulUnion do
  subject { OmniAuth::Strategies::WonderfulUnion.new({}) }

  context "options" do
    it { expect(subject.options.name).to eq("wonderful_union") }
  end

  context "client options" do
    let(:client_options) { subject.options.client_options }

    it "has default name" do
      expect(client_options.site).
        to eq OmniAuth::Strategies::WonderfulUnion::SITE_URL
    end

    it "has default authorize url" do
      expect(client_options.authorize_url).
        to eq("https://my.wun.io/oauth/authorize")
    end

    it "has default token url" do
      expect(client_options.token_url).
        to eq("https://my.wun.io/oauth/token")
    end

    context "can be overridden" do
      let(:client_options_strategy) do
        described_class.new(
          "A_KEY",
          "A_SECRET",
          client_options: {
            site: "http://localhost:4000",
            authorize_url: "http://localhost:5000/auth",
            token_url: "http://localhost:6000/token"
          }
        )
      end

      it "for site" do
        expect(client_options_strategy.options.client_options.site).
          to eq("http://localhost:4000")
      end

      it "for authorize url" do
        expect(client_options_strategy.options.client_options.authorize_url).
          to eq("http://localhost:5000/auth")
      end

      it "for token url" do
        expect(client_options_strategy.options.client_options.token_url).
          to eq("http://localhost:6000/token")
      end
    end
  end

  context "info" do
    it "retuns user email" do
      allow(subject).to receive(:raw_info).and_return(raw_info_hash)

      expect(subject.info["email"]).to eq raw_info_hash["email"]
    end
  end

  private

  def raw_info_hash
    { email: "foo@example.com" }
  end
end
